==> odoo12-addon-login_user_detail-12.0.1.0.2.99.dev1.tar.gz: odoo12-addon-login_user_detail-12.0.1.0.2.99.dev1/odoo/addons/login_user_detail/__manifest__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    Cybrosys Technologies Pvt. Ltd.
#    Copyright (C) 2016-TODAY Cybrosys Technologies(<https://www.cybrosys.com>).
#    Author: Saritha Sahadevan(<https://www.cybrosys.com>)
#    you can modify it under the terms of the GNU LESSER
#    GENERAL PUBLIC LICENSE (LGPL v3), Version 3.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU LESSER GENERAL PUBLIC LICENSE (LGPL v3) for more details.
#
#    You should have received a copy of the GNU LESSER GENERAL PUBLIC LICENSE
#    GENERAL PUBLIC LICENSE (LGPL v3) along with this program.
#    If not, see <https://www.gnu.org/licenses/>.
#
##############################################################################
{
    "name": "User Log Details",
    "version": "12.0.1.0.2",
    "summary": """Login User Details & IP Address""",
    "description": """This module records login information of user""",
    "author": "Cybrosys Techno Solutions ",
    "company": "Cybrosys Techno Solutions ",
    "maintainer": "Cybrosys Techno Solutions",
    "website": "https://www.cybrosys.com",
    "category": "Tools",
    "depends": ["base"],
    "license": "LGPL-3",
    "data": ["security/ir.model.access.csv", "views/login_user_views.xml"],
    "demo": [],
    "images": ["static/description/banner.png"],
}

==> odoo12-addon-login_user_detail-12.0.1.0.3.tar.gz: odoo12-addon-login_user_detail-12.0.1.0.3/odoo/addons/login_user_detail/__manifest__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    Cybrosys Technologies Pvt. Ltd.
#    Copyright (C) 2016-TODAY Cybrosys Technologies(<https://www.cybrosys.com>).
#    Author: Saritha Sahadevan(<https://www.cybrosys.com>)
#    you can modify it under the terms of the GNU LESSER
#    GENERAL PUBLIC LICENSE (LGPL v3), Version 3.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU LESSER GENERAL PUBLIC LICENSE (LGPL v3) for more details.
#
#    You should have received a copy of the GNU LESSER GENERAL PUBLIC LICENSE
#    GENERAL PUBLIC LICENSE (LGPL v3) along with this program.
#    If not, see <https://www.gnu.org/licenses/>.
#
##############################################################################
{
    "name": "User Log Details",
    "version": "12.0.1.0.3",
    "summary": """Login User Details & IP Address""",
    "description": """This module records login information of user""",
    "author": "Cybrosys Techno Solutions ",
    "company": "Cybrosys Techno Solutions ",
    "maintainer": "Cybrosys Techno Solutions",
    "website": "https://www.cybrosys.com",
    "category": "Tools",
    "depends": ["base", "auth_oidc"],
    "license": "LGPL-3",
    "data": ["security/ir.model.access.csv", "views/login_user_views.xml"],
    "demo": [],
    "images": ["static/description/banner.png"],
}
